==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/el-GR/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Υπάρχει ήδη λογαριασμός με το ίδιο email.',
    'account_not_found'      => 'Το όνομα χρήστη ή ο κωδικός πρόσβασης είναι εσφαλμένα.',
    'account_not_activated'  => 'Αυτός ο λογαριασμός χρήστη δεν είναι ενεργοποιημένος.',
    'account_suspended'      => 'Αυτός ο λογαριασμός χρήστη έχει ανασταλεί.',
    'account_banned'         => 'Αυτός ο λογαριασμός χρήστη έχει απαγορευτεί.',
    'throttle'               => 'Πάρα πολλές αποτυχημένες προσπάθειες σύνδεσης. Παρακαλώ δοκιμάστε ξανά σε :minutes λεπτά.',

    'two_factor' => array(
        'already_enrolled'      => 'Η συσκευή σας έχει ήδη εγγραφεί.',
        'success'               => 'Έχετε συνδεθεί επιτυχώς.',
        'code_required'         => 'Απαιτείται διψήφιος κωδικός.',
        'invalid_code'          => 'Ο κωδικός δύο παραγόντων δεν είναι έγκυρος.',
    ),

    'signin' => array(
        'error'   => 'Υπήρχε ένα πρόβλημα ενώ προσπαθείτε να συνδεθείτε, παρακαλώ προσπαθήστε ξανά.',
        'success' => 'Έχετε συνδεθεί επιτυχώς.',
    ),

    'logout' => array(
        'error'   => 'Παρουσιάστηκε πρόβλημα κατά την προσπάθεια αποσύνδεσης σας, παρακαλώ προσπαθήστε ξανά.',
        'success' => 'Έχετε αποσυνδεθεί επιτυχώς.',
    ),

    'signup' => array(
        'error'   => 'Παρουσιάστηκε πρόβλημα κατά την προσπάθεια δημιουργίας του λογαριασμού σας, δοκιμάστε ξανά.',
        'success' => 'Ο λογαριασμός δημιουργήθηκε επιτυχώς.',
    ),

    'forgot-password' => array(
        'error'   => 'Παρουσιάστηκε πρόβλημα κατά την προσπάθεια λήψης νέου κωδικού πρόσβασης κωδικού πρόσβασης, δοκιμάστε ξανά.',
        'success' => 'Αν αυτή η διεύθυνση ηλεκτρονικού ταχυδρομείου υπάρχει στο σύστημά μας, έχει σταλεί ένα email ανάκτησης κωδικού πρόσβασης.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Υπήρχε ένα πρόβλημα ενώ προσπαθούσατε να επαναγέρετε τον κωδικό σας, παρακαλώ προσπαθήστε ξανά.',
        'success' => 'Έχει γίνει επαναφορά του κωδικού πρόσβασής σας με επιτυχία.',
    ),


);

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/el-GR/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Υπάρχει ήδη λογαριασμός με το ίδιο email.',
    'account_not_found'      => 'Το όνομα χρήστη ή ο κωδικός πρόσβασης είναι εσφαλμένα.',
    'account_not_activated'  => 'Αυτός ο λογαριασμός χρήστη δεν είναι ενεργοποιημένος.',
    'account_suspended'      => 'Αυτός ο λογαριασμός χρήστη έχει ανασταλεί.',
    'account_banned'         => 'Αυτός ο λογαριασμός χρήστη έχει απαγορευτεί.',
    'throttle'               => 'Πάρα πολλές αποτυχημένες προσπάθειες σύνδεσης. Παρακαλώ δοκιμάστε ξανά σε :minutes λεπτά.',

    'two_factor' => array(
        'already_enrolled'      => 'Η συσκευή σας έχει ήδη εγγραφεί.',
        'success'               => 'Έχετε συνδεθεί επιτυχώς.',
        'code_required'         => 'Απαιτείται διψήφιος κωδικός.',
        'invalid_code'          => 'Ο κωδικός δύο παραγόντων δεν είναι έγκυρος.',
        'enter_two_factor_code' => 'Please enter your two-factor authentication code.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Υπήρχε ένα πρόβλημα ενώ προσπαθείτε να συνδεθείτε, παρακαλώ προσπαθήστε ξανά.',
        'success' => 'Έχετε συνδεθεί επιτυχώς.',
    ),

    'logout' => array(
        'error'   => 'Παρουσιάστηκε πρόβλημα κατά την προσπάθεια αποσύνδεσης σας, παρακαλώ προσπαθήστε ξανά.',
        'success' => 'Έχετε αποσυνδεθεί επιτυχώς.',
    ),

    'signup' => array(
        'error'   => 'Παρουσιάστηκε πρόβλημα κατά την προσπάθεια δημιουργίας του λογαριασμού σας, δοκιμάστε ξανά.',
        'success' => 'Ο λογαριασμός δημιουργήθηκε επιτυχώς.',
    ),

    'forgot-password' => array(
        'error'   => 'Παρουσιάστηκε πρόβλημα κατά την προσπάθεια λήψης νέου κωδικού πρόσβασης κωδικού πρόσβασης, δοκιμάστε ξανά.',
        'success' => 'Αν αυτή η διεύθυνση ηλεκτρονικού ταχυδρομείου υπάρχει στο σύστημά μας, έχει σταλεί ένα email ανάκτησης κωδικού πρόσβασης.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Υπήρχε ένα πρόβλημα ενώ προσπαθούσατε να επαναγέρετε τον κωδικό σας, παρακαλώ προσπαθήστε ξανά.',
        'success' => 'Έχει γίνει επαναφορά του κωδικού πρόσβασής σας με επιτυχία.',
    ),


);
